/**
    (C) Copyright 2011 Dominik Wagenfuehr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this program. If not, see
    <http://www.gnu.org/licenses/>.
*/

#ifndef BOTDATA_HH
#define BOTDATA_HH

#include <vector>

/// Bot-Daten eines Spiels.
/**
 * Die Klasse enthaelt die Rundenanzahl und die
 * erreichten Punkte der beteiligten Bots.
 */
class BotData
{
  public:
    /// Konstruktor.
    BotData();

    /// Setzt alle Daten zurueck.
    void reset();

    /// Speichere Anzahl an Runden.
    void setRounds( const int value );
      
    /// Eine neue Runde wird gestartet.
    /**
     * Der Rundenzaehler wird entsprechend erhoeht.
     */
    void startNewRound();

    /// Fuegt erreichte Punktzahl hinzu.
    void addPoints( const int points );
    
    /// Fuegt erreichte Punktzahl des Gegners hinzu.
    void addOpponentPoints( const int points );

 	void setMyLastOffer(const int offer);

	void setOpponentLastOffer(const int offer);

	void setOpponentLastAccepted(const bool accepted);

	void setOpponentLast2Rejected(const bool rejected);

	void addMyAccept(const int offer);

	void addOpponentAccept(const int offer);
   
	int getMyAcceptAvg() const;

	int getOpponentAcceptAvg() const;

  public:
    /// Gibt die Anzahl der zu spielenden Runden zurueck.
    int getNumRounds() const
    {
        return mNumMaxRounds;
    }
  
    /// Gibt die aktuelle Runde zurueck.
    int getRound() const
    {
        return mRound;
    }

    /// Gibt die eigene Punktzahl zurueck.
    int getPoints() const
    {
        return mPoints;
    }

    /// Gibt die Punktzahl des Gegners zurueck.
    int getOpponentPoints() const
    {
        return mOpponentPoints;
    }

	/// Gibt mein letztes Angebot zurueck.
	int getMyLastOffer() const {
		return my_last_offer;
	}

	/// Gibt das letzte Angebot des Gegner zurueck.
	int getOpponentLastOffer() const {
		return opponent_last_offer;
	}

	/// Gibt zurueck, ob der Gegner mein letztes Angebot angenommen hat.
	bool getOpponentLastAccepted() const {
		return opponent_last_accepted;
	}

	/// Gibt zurueck, ob der Gegner meine letzten 2 Angebote abgelehnt hat.
	bool getOpponentLast2Rejected() const {
		return opponent_last2_rejected;
	}

	/// Gibt einen Vector mit Angeboten zurueck, die ich aktzeptiert habe.
	std::vector<int> * getIAccepted() {
		return &i_accepted;
	}

	/// Gibt einen Vector mit Angeboten zurueck, die der Gegner aktzeptiert hat.
	std::vector<int> * getOpponentAccepted() {
		return &opponent_accepted;
	}


  private:
    /// Gesamtzahl an Runden.
    int mNumMaxRounds;

    /// Rundennummer.
    /**
     * Mit jedem Start wird die Rundennummer erhoeht.
     * Die Nummer gibt auch an, auf wie viele Daten aus
     * vergangenen Runden man zugreifen kann.
     */
    int mRound;

    /// Eigene bereits erreichte Punktzahl.
    int mPoints;

    /// Punktzahl des Gegners.
    int mOpponentPoints;

	
	int my_last_offer;

	int opponent_last_offer;

	bool opponent_last_accepted;

	bool opponent_last2_rejected;

	std::vector<int> i_accepted;

	std::vector<int> opponent_accepted;
};

#endif // BOTDATA_HH
