#!/usr/bin/tclsh

set filename [lindex $argv 0]

# Datei oeffnen
set infile [open $filename r]

set lineNumber 0
set altLine 0

# Ueber Datei zeilenweise iterieren
while { [gets $infile line] >= 0 } {

    incr lineNumber

    # Suche die naechste Botzeile
    if  { [regexp {^\(II\) BOT1: (.*) *BOT2: (.*)$} $line temp temp1 temp2] } {

        # Sicherheitsabfrage
        incr altLine
        if { [expr $altLine%2] != 1 } {
            error "B: Line $lineNumber: $line"
        }

        # Speichere die Botbezeichnung
        set bot1 [string trim $temp1]
        set bot2 [string trim $temp2]

        foreach bot [list $bot1 $bot2]  {
            # Erstelle Array, falls es das noch nicht gibt
            if { ![info exists pointsPos($bot)] } {
                set pointsPos($bot) 0
                set pointsNeg($bot) 0
                set won($bot) 0
                set lost($bot) 0
                set draw($bot) 0
            }
        }
    } elseif { [regexp {\(II\) Runden:.*Spieler 1: (.*) Spieler 2: (.*)$} $line temp temp1 temp2] } {
        
        # Sicherheitsabfrage
        incr altLine
        if { [expr $altLine%2] != 0 } {
            error "P: Line $lineNumber: $line"
        }

        # Wir addieren nur, wenn zwei unterschiedliche Bots
        # gegeneinander spielen
        # [string compare $bot1 $bot2]
        if { [string compare $bot1 $bot2] } {
            incr pointsPos($bot1) $temp1
            incr pointsNeg($bot1) $temp2
            incr pointsPos($bot2) $temp2
            incr pointsNeg($bot2) $temp1
            if { $temp1 > $temp2 } {
                incr won($bot1)
                incr lost($bot2)
            } elseif { $temp1 < $temp2 } {
                incr won($bot2)
                incr lost($bot1)
            } else {
                incr draw($bot2)
                incr draw($bot1)
            }
        }
    }
    # Alle anderen Zeilen ignorieren wir.
}

# Datei schliessen
close $infile

# Sortierte Ausgabe der Tabelle
set formatString "%3s %45s %10s %10s %4s %4s %4s"
puts [format $formatString "" "Bot" "Plus" "Minus" "Won" "Draw" "Lost"]

set counter 0

while { [llength [array names pointsPos]] > 0 } {

    set bestbot ""
    foreach index [array names pointsPos] {

        # Suche Spieler mit meisten Plus-Punkten
        # bei Gleichstand mit !hohen" Negativ-Punkten
        if { [string length $bestbot] == 0 } {
            set bestbot $index
        } else {
            if { ( $pointsPos($index) > $pointsPos($bestbot) ) ||
                 ( ( $pointsPos($index) == $pointsPos($bestbot) ) &&
                   ( $pointsNeg($index) > $pointsPos($bestbot) ) ) } {
                set bestbot $index
            }
        }
    }

    # Ausgabe
    incr counter
    puts [format $formatString "$counter." "\"$bestbot\"" \
          $pointsPos($bestbot) $pointsNeg($bestbot) \
          $won($bestbot) $draw($bestbot) $lost($bestbot) ]

    # Bot aus Array loeschen
    unset pointsPos($bestbot)
}

